==> skywalking-nodejs-src-0.3.0.tgz: src/proto/language-agent/JVMMetric_grpc_pb.d.ts <==
// package: 
// file: language-agent/JVMMetric.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "grpc";
import * as language_agent_JVMMetric_pb from "../language-agent/JVMMetric_pb";
import * as common_Common_pb from "../common/Common_pb";

interface IJVMMetricReportServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: IJVMMetricReportServiceService_Icollect;
}

interface IJVMMetricReportServiceService_Icollect extends grpc.MethodDefinition<language_agent_JVMMetric_pb.JVMMetricCollection, common_Common_pb.Commands> {
    path: "/JVMMetricReportService/collect";
    requestStream: false;
    responseStream: false;
    requestSerialize: grpc.serialize<language_agent_JVMMetric_pb.JVMMetricCollection>;
    requestDeserialize: grpc.deserialize<language_agent_JVMMetric_pb.JVMMetricCollection>;
    responseSerialize: grpc.serialize<common_Common_pb.Commands>;
    responseDeserialize: grpc.deserialize<common_Common_pb.Commands>;
}

export const JVMMetricReportServiceService: IJVMMetricReportServiceService;

export interface IJVMMetricReportServiceServer {
    collect: grpc.handleUnaryCall<language_agent_JVMMetric_pb.JVMMetricCollection, common_Common_pb.Commands>;
}

export interface IJVMMetricReportServiceClient {
    collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

export class JVMMetricReportServiceClient extends grpc.Client implements IJVMMetricReportServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: object);
    public collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

==> skywalking-nodejs-src-0.4.0.tgz: src/proto/language-agent/JVMMetric_grpc_pb.d.ts <==
// package: 
// file: language-agent/JVMMetric.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "@grpc/grpc-js";
import * as language_agent_JVMMetric_pb from "../language-agent/JVMMetric_pb";
import * as common_Common_pb from "../common/Common_pb";

interface IJVMMetricReportServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: IJVMMetricReportServiceService_Icollect;
}

interface IJVMMetricReportServiceService_Icollect extends grpc.MethodDefinition<language_agent_JVMMetric_pb.JVMMetricCollection, common_Common_pb.Commands> {
    path: "/JVMMetricReportService/collect";
    requestStream: false;
    responseStream: false;
    requestSerialize: grpc.serialize<language_agent_JVMMetric_pb.JVMMetricCollection>;
    requestDeserialize: grpc.deserialize<language_agent_JVMMetric_pb.JVMMetricCollection>;
    responseSerialize: grpc.serialize<common_Common_pb.Commands>;
    responseDeserialize: grpc.deserialize<common_Common_pb.Commands>;
}

export const JVMMetricReportServiceService: IJVMMetricReportServiceService;

export interface IJVMMetricReportServiceServer extends grpc.UntypedServiceImplementation {
    collect: grpc.handleUnaryCall<language_agent_JVMMetric_pb.JVMMetricCollection, common_Common_pb.Commands>;
}

export interface IJVMMetricReportServiceClient {
    collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

export class JVMMetricReportServiceClient extends grpc.Client implements IJVMMetricReportServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: Partial<grpc.ClientOptions>);
    public collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_JVMMetric_pb.JVMMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}
